@@ -51,6 +51,7 @@ __all__ = [
     "serialize_node",
     "serialize_shape_into",
     "serialize_reference_attribute_into",
+    "serialize_reference_attribute",
     "serialize_tensor_into",
     "serialize_tensor",
     "serialize_type_into",
@@ -286,7 +287,7 @@ def to_proto(ir_object: object) -> object:
         return serialize_attribute(ir_object)
     if isinstance(ir_object, _protocols.ReferenceAttributeProtocol):
         assert ir_object.is_ref()
-        return serialize_reference_attribute_into(onnx.AttributeProto(), ir_object)
+        return serialize_reference_attribute(ir_object)
     if isinstance(ir_object, _protocols.TypeProtocol):
         return serialize_type_into(onnx.TypeProto(), ir_object)
     if isinstance(ir_object, _protocols.GraphViewProtocol):
@@ -390,6 +391,10 @@ class TensorProtoTensor(_core.TensorBase):  # pylint: disable=too-many-ancestors
                 return _type_casting.unpack_4bitx2(
                     np.frombuffer(self._proto.raw_data, dtype=np.uint8), shape
                 ).view(dtype.numpy())
+            if dtype.bitwidth == 2:
+                return _type_casting.unpack_2bitx4(
+                    np.frombuffer(self._proto.raw_data, dtype=np.uint8), shape
+                ).view(dtype.numpy())
             return np.frombuffer(
                 self._proto.raw_data, dtype=dtype.numpy().newbyteorder("<")
             ).reshape(shape)
@@ -408,9 +413,11 @@ class TensorProtoTensor(_core.TensorBase):  # pylint: disable=too-many-ancestors
                 _enums.DataType.FLOAT8E8M0,
                 _enums.DataType.INT16,
                 _enums.DataType.INT32,
+                _enums.DataType.INT2,
                 _enums.DataType.INT4,
                 _enums.DataType.INT8,
                 _enums.DataType.UINT16,
+                _enums.DataType.UINT2,
                 _enums.DataType.UINT4,
                 _enums.DataType.UINT8,
             }, f"Unsupported dtype {dtype} for int32_data"
@@ -426,6 +433,10 @@ class TensorProtoTensor(_core.TensorBase):  # pylint: disable=too-many-ancestors
                 return _type_casting.unpack_4bitx2(array.astype(np.uint8), shape).view(
                     dtype.numpy()
                 )
+            if dtype.bitwidth == 2:
+                return _type_casting.unpack_2bitx4(array.astype(np.uint8), shape).view(
+                    dtype.numpy()
+                )
             raise ValueError(
                 f"Unsupported dtype {dtype} for int32_data with bitwidth {dtype.bitwidth}"
             )
@@ -507,11 +518,13 @@ class TensorProtoTensor(_core.TensorBase):  # pylint: disable=too-many-ancestors
                 _enums.DataType.FLOAT8E5M2,
                 _enums.DataType.FLOAT8E5M2FNUZ,
                 _enums.DataType.FLOAT8E8M0,
+                _enums.DataType.INT2,
                 _enums.DataType.INT4,
+                _enums.DataType.UINT2,
                 _enums.DataType.UINT4,
                 _enums.DataType.FLOAT4E2M1,
             }:
-                # uint4 and int4 values are already packed, even when stored as int32
+                # uint2, uint4, int2 and int4 values are already packed, even when stored as int32
                 # so we don't need to pack them again
                 return array.astype(_little_endian_dtype(np.uint8)).tobytes()
             assert self.dtype == _enums.DataType.INT32
@@ -1896,6 +1909,14 @@ def serialize_reference_attribute_into(
     attribute_proto.type = typing.cast(onnx.AttributeProto.AttributeType, from_.type.value)
 
 
+def serialize_reference_attribute(
+    attr: _protocols.ReferenceAttributeProtocol,
+) -> onnx.AttributeProto:
+    attr_proto = onnx.AttributeProto()
+    serialize_reference_attribute_into(attr_proto, attr)
+    return attr_proto
+
+
 def serialize_value(value: _protocols.ValueProtocol, *, name: str = "") -> onnx.ValueInfoProto:
     """Serialize a value into a ValueInfoProto.
 
