@@ -282,6 +282,13 @@ class TensorProtoTensorTest(unittest.TestCase):
             ("INT32", onnx.TensorProto.INT32),
             ("INT64", onnx.TensorProto.INT64),
             ("INT4", onnx.TensorProto.INT4),
+            *(
+                [
+                    ("INT2", onnx.TensorProto.INT2),
+                ]
+                if hasattr(onnx.TensorProto, "INT2")
+                else []
+            ),
         ]
     )
     def test_tensor_proto_tensor_int(self, _: str, dtype: int):
@@ -300,8 +307,11 @@ class TensorProtoTensorTest(unittest.TestCase):
         array_from_raw_data = onnx.numpy_helper.to_array(tensor_proto_from_raw_data)
         np.testing.assert_array_equal(array_from_raw_data, expected_array)
         # Test dlpack
-        if dtype == onnx.TensorProto.INT4:
-            return  # DL Pack does not support int4
+        if dtype in (
+            onnx.TensorProto.INT4,
+            onnx.TensorProto.INT2 if hasattr(onnx.TensorProto, "INT2") else 26,
+        ):
+            return  # DL Pack does not support int4/int2
         np.testing.assert_array_equal(np.from_dlpack(tensor), tensor.numpy())
 
     @parameterized.parameterized.expand(
@@ -311,6 +321,13 @@ class TensorProtoTensorTest(unittest.TestCase):
             ("UINT32", onnx.TensorProto.UINT32),
             ("UINT64", onnx.TensorProto.UINT64),
             ("UINT4", onnx.TensorProto.UINT4),
+            *(
+                [
+                    ("INT2", onnx.TensorProto.UINT2),
+                ]
+                if hasattr(onnx.TensorProto, "UINT2")
+                else []
+            ),
         ]
     )
     def test_tensor_proto_tensor_uint(self, _: str, dtype: int):
@@ -327,8 +344,11 @@ class TensorProtoTensorTest(unittest.TestCase):
         array_from_raw_data = onnx.numpy_helper.to_array(tensor_proto_from_raw_data)
         np.testing.assert_array_equal(array_from_raw_data, expected_array)
         # Test dlpack
-        if dtype == onnx.TensorProto.UINT4:
-            return  # DL Pack does not support uint4
+        if dtype in (
+            onnx.TensorProto.UINT4,
+            onnx.TensorProto.UINT2 if hasattr(onnx.TensorProto, "UINT2") else 25,
+        ):
+            return  # DL Pack does not support uint4/uint2
         np.testing.assert_array_equal(np.from_dlpack(tensor), tensor.numpy())
 
     @parameterized.parameterized.expand(
@@ -398,6 +418,8 @@ class TensorProtoTensorTest(unittest.TestCase):
                     ("FLOAT8E8M0", ir.DataType.FLOAT8E8M0),
                     ("UINT4", ir.DataType.UINT4),
                     ("INT4", ir.DataType.INT4),
+                    ("UINT2", ir.DataType.UINT2),
+                    ("INT2", ir.DataType.INT2),
                     ("FLOAT4E2M1", ir.DataType.FLOAT4E2M1),
                 ],
                 [
